@@ -1,18 +1,55 @@
-#[doc = "Reader of register INTENCLR"]
-pub type R = crate::R<u32, super::INTENCLR>;
-#[doc = "Writer for register INTENCLR"]
-pub type W = crate::W<u32, super::INTENCLR>;
-#[doc = "Register INTENCLR `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENCLR {
-    type Type = u32;
+#[doc = "Register `INTENCLR` reader"]
+pub struct R(crate::R<INTENCLR_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENCLR_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `OVR0`"]
-pub type OVR0_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR0`"]
+impl From<crate::R<INTENCLR_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENCLR_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENCLR` writer"]
+pub struct W(crate::W<INTENCLR_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENCLR_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENCLR_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENCLR_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `OVR0` reader - Channel 0 Overrun Interrupt Enable"]
+pub struct OVR0_R(crate::FieldReader<bool, bool>);
+impl OVR0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR0_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR0_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR0` writer - Channel 0 Overrun Interrupt Enable"]
 pub struct OVR0_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +67,26 @@ impl<'a> OVR0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
-#[doc = "Reader of field `OVR1`"]
-pub type OVR1_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR1`"]
+#[doc = "Field `OVR1` reader - Channel 1 Overrun Interrupt Enable"]
+pub struct OVR1_R(crate::FieldReader<bool, bool>);
+impl OVR1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR1_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR1_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR1` writer - Channel 1 Overrun Interrupt Enable"]
 pub struct OVR1_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +104,26 @@ impl<'a> OVR1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `OVR2`"]
-pub type OVR2_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR2`"]
+#[doc = "Field `OVR2` reader - Channel 2 Overrun Interrupt Enable"]
+pub struct OVR2_R(crate::FieldReader<bool, bool>);
+impl OVR2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR2_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR2_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR2` writer - Channel 2 Overrun Interrupt Enable"]
 pub struct OVR2_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +141,26 @@ impl<'a> OVR2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `OVR3`"]
-pub type OVR3_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR3`"]
+#[doc = "Field `OVR3` reader - Channel 3 Overrun Interrupt Enable"]
+pub struct OVR3_R(crate::FieldReader<bool, bool>);
+impl OVR3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR3_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR3_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR3` writer - Channel 3 Overrun Interrupt Enable"]
 pub struct OVR3_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +178,26 @@ impl<'a> OVR3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `OVR4`"]
-pub type OVR4_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR4`"]
+#[doc = "Field `OVR4` reader - Channel 4 Overrun Interrupt Enable"]
+pub struct OVR4_R(crate::FieldReader<bool, bool>);
+impl OVR4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR4_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR4_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR4` writer - Channel 4 Overrun Interrupt Enable"]
 pub struct OVR4_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +215,26 @@ impl<'a> OVR4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `OVR5`"]
-pub type OVR5_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR5`"]
+#[doc = "Field `OVR5` reader - Channel 5 Overrun Interrupt Enable"]
+pub struct OVR5_R(crate::FieldReader<bool, bool>);
+impl OVR5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR5_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR5_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR5` writer - Channel 5 Overrun Interrupt Enable"]
 pub struct OVR5_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +252,26 @@ impl<'a> OVR5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `OVR6`"]
-pub type OVR6_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR6`"]
+#[doc = "Field `OVR6` reader - Channel 6 Overrun Interrupt Enable"]
+pub struct OVR6_R(crate::FieldReader<bool, bool>);
+impl OVR6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR6_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR6_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR6` writer - Channel 6 Overrun Interrupt Enable"]
 pub struct OVR6_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +289,26 @@ impl<'a> OVR6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
-#[doc = "Reader of field `OVR7`"]
-pub type OVR7_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR7`"]
+#[doc = "Field `OVR7` reader - Channel 7 Overrun Interrupt Enable"]
+pub struct OVR7_R(crate::FieldReader<bool, bool>);
+impl OVR7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR7_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR7_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR7` writer - Channel 7 Overrun Interrupt Enable"]
 pub struct OVR7_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +326,26 @@ impl<'a> OVR7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `EVD0`"]
-pub type EVD0_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD0`"]
+#[doc = "Field `EVD0` reader - Channel 0 Event Detection Interrupt Enable"]
+pub struct EVD0_R(crate::FieldReader<bool, bool>);
+impl EVD0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD0_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD0_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD0` writer - Channel 0 Event Detection Interrupt Enable"]
 pub struct EVD0_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +363,26 @@ impl<'a> EVD0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `EVD1`"]
-pub type EVD1_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD1`"]
+#[doc = "Field `EVD1` reader - Channel 1 Event Detection Interrupt Enable"]
+pub struct EVD1_R(crate::FieldReader<bool, bool>);
+impl EVD1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD1_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD1_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD1` writer - Channel 1 Event Detection Interrupt Enable"]
 pub struct EVD1_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +400,26 @@ impl<'a> EVD1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `EVD2`"]
-pub type EVD2_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD2`"]
+#[doc = "Field `EVD2` reader - Channel 2 Event Detection Interrupt Enable"]
+pub struct EVD2_R(crate::FieldReader<bool, bool>);
+impl EVD2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD2_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD2_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD2` writer - Channel 2 Event Detection Interrupt Enable"]
 pub struct EVD2_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +437,26 @@ impl<'a> EVD2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `EVD3`"]
-pub type EVD3_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD3`"]
+#[doc = "Field `EVD3` reader - Channel 3 Event Detection Interrupt Enable"]
+pub struct EVD3_R(crate::FieldReader<bool, bool>);
+impl EVD3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD3_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD3_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD3` writer - Channel 3 Event Detection Interrupt Enable"]
 pub struct EVD3_W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +474,26 @@ impl<'a> EVD3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `EVD4`"]
-pub type EVD4_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD4`"]
+#[doc = "Field `EVD4` reader - Channel 4 Event Detection Interrupt Enable"]
+pub struct EVD4_R(crate::FieldReader<bool, bool>);
+impl EVD4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD4_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD4_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD4` writer - Channel 4 Event Detection Interrupt Enable"]
 pub struct EVD4_W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +511,26 @@ impl<'a> EVD4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `EVD5`"]
-pub type EVD5_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD5`"]
+#[doc = "Field `EVD5` reader - Channel 5 Event Detection Interrupt Enable"]
+pub struct EVD5_R(crate::FieldReader<bool, bool>);
+impl EVD5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD5_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD5_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD5` writer - Channel 5 Event Detection Interrupt Enable"]
 pub struct EVD5_W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +548,26 @@ impl<'a> EVD5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `EVD6`"]
-pub type EVD6_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD6`"]
+#[doc = "Field `EVD6` reader - Channel 6 Event Detection Interrupt Enable"]
+pub struct EVD6_R(crate::FieldReader<bool, bool>);
+impl EVD6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD6_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD6_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD6` writer - Channel 6 Event Detection Interrupt Enable"]
 pub struct EVD6_W<'a> {
     w: &'a mut W,
 }
@@ -366,13 +585,26 @@ impl<'a> EVD6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
-#[doc = "Reader of field `EVD7`"]
-pub type EVD7_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD7`"]
+#[doc = "Field `EVD7` reader - Channel 7 Event Detection Interrupt Enable"]
+pub struct EVD7_R(crate::FieldReader<bool, bool>);
+impl EVD7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD7_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD7_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD7` writer - Channel 7 Event Detection Interrupt Enable"]
 pub struct EVD7_W<'a> {
     w: &'a mut W,
 }
@@ -390,13 +622,26 @@ impl<'a> EVD7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `OVR8`"]
-pub type OVR8_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR8`"]
+#[doc = "Field `OVR8` reader - Channel 8 Overrun Interrupt Enable"]
+pub struct OVR8_R(crate::FieldReader<bool, bool>);
+impl OVR8_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR8_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR8_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR8` writer - Channel 8 Overrun Interrupt Enable"]
 pub struct OVR8_W<'a> {
     w: &'a mut W,
 }
@@ -414,13 +659,26 @@ impl<'a> OVR8_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `OVR9`"]
-pub type OVR9_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR9`"]
+#[doc = "Field `OVR9` reader - Channel 9 Overrun Interrupt Enable"]
+pub struct OVR9_R(crate::FieldReader<bool, bool>);
+impl OVR9_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR9_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR9_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR9` writer - Channel 9 Overrun Interrupt Enable"]
 pub struct OVR9_W<'a> {
     w: &'a mut W,
 }
@@ -438,13 +696,26 @@ impl<'a> OVR9_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
-#[doc = "Reader of field `OVR10`"]
-pub type OVR10_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR10`"]
+#[doc = "Field `OVR10` reader - Channel 10 Overrun Interrupt Enable"]
+pub struct OVR10_R(crate::FieldReader<bool, bool>);
+impl OVR10_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR10_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR10_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR10` writer - Channel 10 Overrun Interrupt Enable"]
 pub struct OVR10_W<'a> {
     w: &'a mut W,
 }
@@ -462,13 +733,26 @@ impl<'a> OVR10_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
-#[doc = "Reader of field `OVR11`"]
-pub type OVR11_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `OVR11`"]
+#[doc = "Field `OVR11` reader - Channel 11 Overrun Interrupt Enable"]
+pub struct OVR11_R(crate::FieldReader<bool, bool>);
+impl OVR11_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        OVR11_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for OVR11_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `OVR11` writer - Channel 11 Overrun Interrupt Enable"]
 pub struct OVR11_W<'a> {
     w: &'a mut W,
 }
@@ -486,13 +770,26 @@ impl<'a> OVR11_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
-#[doc = "Reader of field `EVD8`"]
-pub type EVD8_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD8`"]
+#[doc = "Field `EVD8` reader - Channel 8 Event Detection Interrupt Enable"]
+pub struct EVD8_R(crate::FieldReader<bool, bool>);
+impl EVD8_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD8_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD8_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD8` writer - Channel 8 Event Detection Interrupt Enable"]
 pub struct EVD8_W<'a> {
     w: &'a mut W,
 }
@@ -510,13 +807,26 @@ impl<'a> EVD8_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | (((value as u32) & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
         self.w
     }
 }
-#[doc = "Reader of field `EVD9`"]
-pub type EVD9_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD9`"]
+#[doc = "Field `EVD9` reader - Channel 9 Event Detection Interrupt Enable"]
+pub struct EVD9_R(crate::FieldReader<bool, bool>);
+impl EVD9_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD9_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD9_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD9` writer - Channel 9 Event Detection Interrupt Enable"]
 pub struct EVD9_W<'a> {
     w: &'a mut W,
 }
@@ -534,13 +844,26 @@ impl<'a> EVD9_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | (((value as u32) & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
         self.w
     }
 }
-#[doc = "Reader of field `EVD10`"]
-pub type EVD10_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD10`"]
+#[doc = "Field `EVD10` reader - Channel 10 Event Detection Interrupt Enable"]
+pub struct EVD10_R(crate::FieldReader<bool, bool>);
+impl EVD10_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD10_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD10_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD10` writer - Channel 10 Event Detection Interrupt Enable"]
 pub struct EVD10_W<'a> {
     w: &'a mut W,
 }
@@ -558,13 +881,26 @@ impl<'a> EVD10_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | (((value as u32) & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
         self.w
     }
 }
-#[doc = "Reader of field `EVD11`"]
-pub type EVD11_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `EVD11`"]
+#[doc = "Field `EVD11` reader - Channel 11 Event Detection Interrupt Enable"]
+pub struct EVD11_R(crate::FieldReader<bool, bool>);
+impl EVD11_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EVD11_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EVD11_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EVD11` writer - Channel 11 Event Detection Interrupt Enable"]
 pub struct EVD11_W<'a> {
     w: &'a mut W,
 }
@@ -582,7 +918,7 @@ impl<'a> EVD11_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | (((value as u32) & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
         self.w
     }
 }
@@ -829,4 +1165,30 @@ impl W {
     pub fn evd11(&mut self) -> EVD11_W {
         EVD11_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Interrupt Enable Clear\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenclr](index.html) module"]
+pub struct INTENCLR_SPEC;
+impl crate::RegisterSpec for INTENCLR_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenclr::R](R) reader structure"]
+impl crate::Readable for INTENCLR_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenclr::W](W) writer structure"]
+impl crate::Writable for INTENCLR_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENCLR to value 0"]
+impl crate::Resettable for INTENCLR_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
